import React from 'https://esm.sh/react@18.2.0'
import {
    ChakraProvider,
    Container,
    Stack,
    Checkbox,
    Alert,
    AlertIcon,
    AlertTitle,
    AlertDescription,
    Divider,
    Tag,
    Heading,
    Box,
    Text,
    Image,
    Center,
    FormControl,
    FormLabel,
    FormHelperText,
    FormErrorMessage,
    Textarea,
    Button,
    Tabs,
    TabList,
    TabPanels,
    Tab,
    TabPanel,
    Input,
    InputGroup,
    InputLeftAddon,
    InputRightElement,
    Icon,
    NumberInput,
    AvatarGroup,
    Avatar,
    AvatarBadge
} from 'https://esm.sh/@chakra-ui/react@2.3.2'
import { CopyIcon } from 'https://esm.sh/@chakra-ui/icons@2.0.9'

const App = () => (
    <ChakraProvider resetCSS>
        <Container>
            <Alert mb="2em">
                <AlertIcon />
                <AlertTitle mr={1} fontWeight="bold">
                    Eclipse Dirigible
                </AlertTitle>
                <AlertDescription>React App with Chakra UI</AlertDescription>
            </Alert>
            <Stack
                spacing={2}
                backgroundColor="blackAlpha.100"
                p="1em"
                opacity={1}
                overflow="visible"
            >
                <Heading as="h1" size="sm">
                    Steps
                </Heading>
                <Checkbox defaultChecked>
                    Create "React UI" project from template
                </Checkbox>
                <Checkbox defaultChecked>Publish Project</Checkbox>
                <Checkbox defaultChecked>Access Application</Checkbox>
                <Checkbox>Unpublish Project</Checkbox>
            </Stack>
            <Divider borderColor="blackAlpha.500" />
            <Center>
                <Image
                    height="150px"
                    width="150px"
                    src="https://www.dirigible.io/api/images/api.svg"
                />
            </Center>
            <FormControl mt="3em">
                <FormLabel>Feedback</FormLabel>
                <FormErrorMessage>Error message</FormErrorMessage>
                <Textarea placeholder="Enter your feedback about Eclipse Dirigible here" />
                <FormHelperText>Send your honest feedback!</FormHelperText>
                <Button variant="solid" size="md" colorScheme="twitter" mt="1em">
                    Send
                </Button>
            </FormControl>
            <Tabs
                size="md"
                isFitted
                variant="line"
                align="center"
                orientation="horizontal"
            >
                <TabList>
                    <Tab>One</Tab>
                    <Tab>Two</Tab>
                </TabList>
                <TabPanels>
                    <TabPanel>
                        <FormControl>
                            <FormLabel>Label</FormLabel>
                            <Input />
                            <FormHelperText>Helper message</FormHelperText>
                            <FormErrorMessage>Error message</FormErrorMessage>
                        </FormControl>
                    </TabPanel>
                    <TabPanel>
                        <InputGroup>
                            <InputLeftAddon>Email</InputLeftAddon>
                            <Input />
                            <InputRightElement>
                                <CopyIcon name="email" />
                            </InputRightElement>
                        </InputGroup>
                    </TabPanel>
                    <TabPanel>
                        <NumberInput />
                        <AvatarGroup spacing={-3} max={3} size="md">
                            <Avatar name="Yordan Pavlov">
                                <AvatarBadge
                                    bg="green.500"
                                    boxSize="1.25rem"
                                    borderColor="white"
                                />
                            </Avatar>
                        </AvatarGroup>
                    </TabPanel>
                </TabPanels>
            </Tabs>
            <Box>
                <Text mt="3em">Tags:</Text>
                <Tag colorScheme="green" rounded="lg">
                    React UI
                </Tag>
                <Tag ml="0.25em" variant="solid" colorScheme="twitter" rounded="lg">
                    sample
                </Tag>
                <Tag ml="0.25em" variant="solid" colorScheme="red" rounded="lg">
                    application
                </Tag>
            </Box>
        </Container>
    </ChakraProvider>
)

export default App